@@ -32,7 +32,6 @@
 #include <config.h>
 #endif
 
-#include "dialogs/gtr-comment-dialog.h"
 #include "gtr-application.h"
 #include "gtr-context.h"
 #include "gtr-io-error-info-bar.h"
@@ -40,8 +39,7 @@
 #include "gtr-msg.h"
 #include "gtr-tab.h"
 #include "gtr-po.h"
-#include "gtr-prefs-manager.h"
-#include "gtr-prefs-manager-app.h"
+#include "gtr-settings.h"
 #include "gtr-view.h"
 #include "gtr-translation-memory.h"
 #include "gtr-translation-memory-ui.h"
@@ -62,74 +60,77 @@
 #define GTR_TAB_KEY "GtrTabFromDocument"
 
 G_DEFINE_TYPE (GtrTab, gtr_tab, GTK_TYPE_VBOX)
-     struct _GtrTabPrivate
-     {
-       GtrPo *po;
 
-       GtkWidget *table_pane;
-       GtkWidget *content_pane;
-       GtkWidget *panel;
-       GtkWidget *message_table;
-       GtkWidget *lateral_panel;        //TM, Context, etc.
+struct _GtrTabPrivate
+{
+  GSettings *files_settings;
+  GSettings *editor_settings;
+  GSettings *state_settings;
 
-       GtkWidget *comment_pane;
-       GtkWidget *context;
-       GtkWidget *translation_memory;
+  GtrPo *po;
 
-       /*Comment button */
-       GtkWidget *comment_button;
+  GtkWidget *table_pane;
+  GtkWidget *content_pane;
+  GtkWidget *message_table;
+  GtkWidget *lateral_panel;        //TM, Context, etc.
 
-       /*Info bar */
-       GtkWidget *infobar;
+  GtkWidget *context_pane;
+  GtkWidget *context;
+  GtkWidget *translation_memory;
 
-       /*Original text */
-       GtkWidget *msgid_hbox;
-       GtkWidget *text_vbox;
-       GtkWidget *text_msgid;
-       GtkWidget *text_plural_scroll;
-       GtkWidget *text_msgid_plural;
+  /*Info bar */
+  GtkWidget *infobar;
 
-       /*Translated text */
-       GtkWidget *msgstr_label;
-       GtkWidget *msgstr_hbox;
-       GtkWidget *trans_notebook;
-       GtkWidget *trans_msgstr[MAX_PLURALS];
+  /*Original text */
+  GtkWidget *msgid_hbox;
+  GtkWidget *text_vbox;
+  GtkWidget *text_msgid;
+  GtkWidget *text_plural_scroll;
+  GtkWidget *text_msgid_plural;
 
-       /*Status widgets */
-       GtkWidget *translated;
-       GtkWidget *fuzzy;
-       GtkWidget *untranslated;
+  /*Translated text */
+  GtkWidget *msgstr_label;
+  GtkWidget *msgstr_hbox;
+  GtkWidget *trans_notebook;
+  GtkWidget *trans_msgstr[MAX_PLURALS];
 
-       /* Autosave */
-       GTimer *timer;
-       gint autosave_interval;
-       guint autosave_timeout;
-       guint autosave:1;
+  /*Status widgets */
+  GtkWidget *translated;
+  GtkWidget *fuzzy;
+  GtkWidget *untranslated;
 
-       /*Blocking movement */
-       guint blocking:1;
-     };
+  /* Autosave */
+  GTimer *timer;
+  gint autosave_interval;
+  guint autosave_timeout;
+  guint autosave : 1;
 
-     enum
-     {
-       SHOWED_MESSAGE,
-       MESSAGE_CHANGED,
-       MESSAGE_EDITION_FINISHED,
-       LAST_SIGNAL
-     };
+  /*Blocking movement */
+  guint blocking : 1;
+};
 
-     enum
-     {
-       PROP_0,
-       PROP_AUTOSAVE,
-       PROP_AUTOSAVE_INTERVAL
-     };
+enum
+{
+  SHOWED_MESSAGE,
+  MESSAGE_CHANGED,
+  MESSAGE_EDITION_FINISHED,
+  LAST_SIGNAL
+};
 
-     static guint signals[LAST_SIGNAL];
+enum
+{
+  PROP_0,
+  PROP_NAME,
+  PROP_AUTOSAVE,
+  PROP_AUTOSAVE_INTERVAL
+};
 
-     static gboolean gtr_tab_autosave (GtrTab * tab);
+static guint signals[LAST_SIGNAL];
 
-     static void install_autosave_timeout (GtrTab * tab)
+static gboolean gtr_tab_autosave (GtrTab * tab);
+
+static void
+install_autosave_timeout (GtrTab * tab)
 {
   gint timeout;
 
@@ -186,29 +187,23 @@ remove_autosave_timeout (GtrTab * tab)
   tab->priv->autosave_timeout = 0;
 }
 
-static void
-gtr_tab_showed_message (GtrTab * tab, GtrMsg * msg)
-{
-  if (strcmp (gtr_msg_get_comment (msg), "") != 0)
-    gtk_widget_show (tab->priv->comment_button);
-  else
-    gtk_widget_hide (tab->priv->comment_button);
-}
-
 static void
 gtr_tab_edition_finished (GtrTab * tab, GtrMsg * msg)
 {
   GtrTranslationMemory *tm;
   gchar *message_error;
   GtkWidget *infobar;
+  GtrHeader *header;
 
-  tm =
-    GTR_TRANSLATION_MEMORY (gtr_application_get_translation_memory (GTR_APP));
+  header = gtr_po_get_header (tab->priv->po);
 
-  if (gtr_msg_is_translated (msg) && !gtr_msg_is_fuzzy (msg))
-    gtr_translation_memory_store (tm,
-                                  gtr_msg_get_msgid (msg),
-                                  gtr_msg_get_msgstr (msg));
+  if (gtr_header_get_profile (header) != NULL)
+    {
+      tm = GTR_TRANSLATION_MEMORY (gtr_application_get_translation_memory (GTR_APP));
+
+      if (gtr_msg_is_translated (msg) && !gtr_msg_is_fuzzy (msg))
+        gtr_translation_memory_store (tm, msg);
+    }
 
   /*
    * Checking message
@@ -245,6 +240,7 @@ gtr_message_translation_update (GtkTextBuffer * textbuffer, GtrTab * tab)
   GtrMsg *msg;
   const gchar *check;
   gchar *translation;
+  gboolean unmark_fuzzy;
   gint i;
 
   /* Work out which message this is associated with */
@@ -254,9 +250,10 @@ gtr_message_translation_update (GtkTextBuffer * textbuffer, GtrTab * tab)
   msg_aux = gtr_po_get_current_message (tab->priv->po);
   msg = msg_aux->data;
   buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tab->priv->trans_msgstr[0]));
+  unmark_fuzzy = g_settings_get_boolean (tab->priv->editor_settings,
+                                         GTR_SETTINGS_UNMARK_FUZZY_WHEN_CHANGED);
 
-  if (gtr_msg_is_fuzzy (msg)
-      && gtr_prefs_manager_get_unmark_fuzzy_when_changed ())
+  if (gtr_msg_is_fuzzy (msg) && unmark_fuzzy)
     gtr_msg_set_fuzzy (msg, FALSE);
 
   if (textbuffer == buf)
@@ -313,12 +310,10 @@ gtr_message_translation_update (GtkTextBuffer * textbuffer, GtrTab * tab)
   g_return_if_reached ();
 }
 
-
-
-
 static GtkWidget *
 gtr_tab_append_msgstr_page (const gchar * tab_label,
-                            GtkWidget * box, gboolean spellcheck)
+                            GtkWidget * box, gboolean spellcheck,
+                            GtrTab *tab)
 {
   GtkWidget *scroll;
   GtkWidget *label;
@@ -332,7 +327,9 @@ gtr_tab_append_msgstr_page (const gchar * tab_label,
   widget = gtr_view_new ();
   gtk_widget_show (widget);
 
-  if (spellcheck && gtr_prefs_manager_get_spellcheck ())
+  if (spellcheck &&
+      g_settings_get_boolean (tab->priv->editor_settings,
+                              GTR_SETTINGS_SPELLCHECK))
     gtr_view_enable_spellcheck (GTR_VIEW (widget), spellcheck);
 
   gtk_container_add (GTK_CONTAINER (scroll), widget);
@@ -377,35 +374,6 @@ gtr_message_plural_forms (GtrTab * tab, GtrMsg * msg)
     }
 }
 
-static GtkWidget *
-gtr_tab_create_comment_button ()
-{
-  GtkWidget *button;
-  GtkWidget *image;
-
-  /* setup close button */
-  button = gtk_button_new ();
-  gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
-  /* don't allow focus on the close button */
-  gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
-
-  image = gtk_image_new_from_stock (GTK_STOCK_INDEX, GTK_ICON_SIZE_MENU);
-  gtk_widget_show (image);
-  gtk_container_add (GTK_CONTAINER (button), image);
-
-  gtk_widget_set_tooltip_text (button, _("Open comment dialog"));
-
-  return button;
-}
-
-static void
-on_comment_button_clicked (GtkButton * button, gpointer useless)
-{
-  GtrWindow *window = gtr_application_get_active_window (GTR_APP);
-
-  gtr_show_comment_dialog (window);
-}
-
 /*
  * gtr_tab_show_message:
  * @tab: a #GtranslationTab
@@ -538,22 +506,6 @@ update_status (GtrTab * tab, GtrMsg * msg, gpointer useless)
     gtr_po_set_state (tab->priv->po, GTR_PO_STATE_MODIFIED);
 }
 
-static void
-comment_pane_position_changed (GObject * tab_gobject,
-                               GParamSpec * arg1, GtrTab * tab)
-{
-  gtr_prefs_manager_set_comment_pane_pos (gtk_paned_get_position
-                                          (GTK_PANED (tab_gobject)));
-}
-
-static void
-content_pane_position_changed (GObject * tab_gobject,
-                               GParamSpec * arg1, GtrTab * tab)
-{
-  gtr_prefs_manager_set_content_pane_pos (gtk_paned_get_position
-                                          (GTK_PANED (tab_gobject)));
-}
-
 static void
 gtr_tab_add_msgstr_tabs (GtrTab * tab)
 {
@@ -570,10 +522,11 @@ gtr_tab_add_msgstr_tabs (GtrTab * tab)
 
   do
     {
-      label = g_strdup_printf (_("Plural %d"), i + 1);
+      label = g_strdup_printf (_("Plural %d"), i);
       priv->trans_msgstr[i] = gtr_tab_append_msgstr_page (label,
                                                           priv->trans_notebook,
-                                                          TRUE);
+                                                          TRUE,
+                                                          tab);
       buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->trans_msgstr[i]));
       g_signal_connect (buf, "end-user-action",
                         G_CALLBACK (gtr_message_translation_update), tab);
@@ -586,93 +539,48 @@ gtr_tab_add_msgstr_tabs (GtrTab * tab)
   while (i < gtr_header_get_nplurals (header));
 }
 
+static void
+on_location_notify (GtrPo      *po,
+                    GParamSpec *pspec,
+                    GtrTab     *tab)
+{
+  g_object_notify (G_OBJECT (tab), "name");
+}
+
+static void
+on_state_notify (GtrPo      *po,
+                 GParamSpec *pspec,
+                 GtrTab     *tab)
+{
+  g_object_notify (G_OBJECT (tab), "name");
+}
+
 static void
 gtr_tab_draw (GtrTab * tab)
 {
   GtkWidget *vertical_box;
-  GtkWidget *label_widget;
+  GtkWidget *vcontext_box;
   GtkWidget *msgid_label;
   GtkWidget *scroll;
   GtrTabPrivate *priv = tab->priv;
 
-  /*
-   * Panel
-   */
-  priv->panel = gtk_notebook_new ();
-  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (priv->panel), GTK_POS_BOTTOM);
-  gtk_widget_show (priv->panel);
+  /* Content pane; this is where the message table and message area go */
+  priv->content_pane = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
+  g_settings_bind (tab->priv->state_settings,
+                   GTR_SETTINGS_CONTENT_PANEL_SIZE,
+                   priv->content_pane,
+                   "position",
+                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+  gtk_widget_show (priv->content_pane);
 
-  /*
-   * Message table
-   */
+  /* Message table */
   priv->message_table = gtr_message_table_new (GTK_WIDGET (tab));
   gtk_widget_show (priv->message_table);
 
-  label_widget = gtk_label_new (_("Message Table"));
-
-  gtk_notebook_append_page (GTK_NOTEBOOK (priv->panel),
-                            priv->message_table, label_widget);
-
-  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (priv->panel), FALSE);
-
-  /*
-   * Comment pane
-   */
-  priv->comment_pane = gtk_hpaned_new ();
-  gtk_paned_set_position (GTK_PANED (priv->comment_pane),
-                          gtr_prefs_manager_get_comment_pane_pos ());
-  g_signal_connect (priv->comment_pane, "notify::position",
-                    G_CALLBACK (comment_pane_position_changed), tab);
-  gtk_widget_show (priv->comment_pane);
-
-  /*
-   * Lateral panel
-   */
-  tab->priv->lateral_panel = gtk_notebook_new ();
-  gtk_widget_show (tab->priv->lateral_panel);
-
-  gtk_paned_pack2 (GTK_PANED (priv->comment_pane), tab->priv->lateral_panel,
-                   TRUE, TRUE);
-
-  /*
-   * Context
-   */
-  priv->context = gtr_context_panel_new (GTK_WIDGET (tab));
-  gtk_widget_show (priv->context);
-  gtr_tab_add_widget_to_lateral_panel (tab, priv->context, _("Context"));
-
-  /*
-   * TM
-   */
-  priv->translation_memory = gtr_translation_memory_ui_new (GTK_WIDGET (tab));
-  gtk_widget_show (priv->translation_memory);
-  gtr_tab_add_widget_to_lateral_panel (tab, priv->translation_memory,
-                                       _("Translation Memory"));
-
-  /*
-   * Content pane; this is where the message table and message area go
-   */
-  priv->content_pane = gtk_vpaned_new ();
-  gtk_paned_set_position (GTK_PANED (priv->content_pane),
-                          gtr_prefs_manager_get_content_pane_pos ());
-  g_signal_connect (priv->content_pane,
-                    "notify::position",
-                    G_CALLBACK (content_pane_position_changed), tab);
-  gtk_widget_show (priv->content_pane);
-
-  /*
-   * Pack the comments pane and the main content
-   */
-  vertical_box = gtk_vbox_new (FALSE, 0);
-  gtk_paned_pack1 (GTK_PANED (priv->content_pane), GTK_WIDGET (priv->panel),
+  gtk_paned_pack1 (GTK_PANED (priv->content_pane), GTK_WIDGET (priv->message_table),
                    TRUE, FALSE);
-  gtk_paned_pack2 (GTK_PANED (priv->content_pane), priv->comment_pane, FALSE,
-                   TRUE);
-  gtk_widget_show (vertical_box);
 
-  /*
-   * Orignal text widgets
-   */
+  /* Orignal text widgets */
   priv->msgid_hbox = gtk_hbox_new (FALSE, 0);
   gtk_widget_show (priv->msgid_hbox);
 
@@ -725,17 +633,15 @@ gtr_tab_draw (GtrTab * tab)
   gtk_box_pack_start (GTK_BOX (priv->text_vbox), priv->text_plural_scroll,
                       TRUE, TRUE, 0);
 
+  vertical_box = gtk_vbox_new (FALSE, 0);
+  gtk_widget_show (vertical_box);
+
   gtk_box_pack_start (GTK_BOX (vertical_box), priv->msgid_hbox, FALSE, FALSE,
                       0);
   gtk_box_pack_start (GTK_BOX (vertical_box), priv->text_vbox, TRUE, TRUE, 0);
 
 
-  /*
-   * Translation widgets
-   */
-  priv->msgstr_hbox = gtk_hbox_new (FALSE, 0);
-  gtk_widget_show (priv->msgstr_hbox);
-
+  /* Translation widgets */
   priv->msgstr_label = gtk_label_new (NULL);
   gtk_label_set_markup_with_mnemonic (GTK_LABEL (priv->msgstr_label),
                                       _("<b>Translate_d Text:</b>"));
@@ -743,28 +649,53 @@ gtr_tab_draw (GtrTab * tab)
   gtk_misc_set_alignment (GTK_MISC (priv->msgstr_label), 0, 0.5);
   gtk_widget_show (priv->msgstr_label);
 
-  gtk_box_pack_start (GTK_BOX (priv->msgstr_hbox), priv->msgstr_label, TRUE,
-                      TRUE, 0);
-
-  priv->comment_button = gtr_tab_create_comment_button ();
-  gtk_box_pack_start (GTK_BOX (priv->msgstr_hbox), priv->comment_button,
-                      FALSE, FALSE, 0);
-  g_signal_connect (priv->comment_button, "clicked",
-                    G_CALLBACK (on_comment_button_clicked), NULL);
-
   priv->trans_notebook = gtk_notebook_new ();
   gtk_notebook_set_show_border (GTK_NOTEBOOK (priv->trans_notebook), FALSE);
   gtk_widget_show (priv->trans_notebook);
 
-  gtk_box_pack_start (GTK_BOX (vertical_box), priv->msgstr_hbox, FALSE, FALSE,
+  gtk_box_pack_start (GTK_BOX (vertical_box), priv->msgstr_label, FALSE, FALSE,
                       0);
   gtk_box_pack_start (GTK_BOX (vertical_box), priv->trans_notebook, TRUE,
                       TRUE, 0);
 
-  gtk_paned_pack1 (GTK_PANED (priv->comment_pane), vertical_box, FALSE,
-                   FALSE);
+  gtk_paned_pack2 (GTK_PANED (priv->content_pane), vertical_box, FALSE,
+                   TRUE);
 
-  gtk_box_pack_start (GTK_BOX (tab), priv->content_pane, TRUE, TRUE, 0);
+  /* Context pane */
+  priv->context_pane = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
+  g_settings_bind (tab->priv->state_settings,
+                   GTR_SETTINGS_CONTEXT_PANEL_SIZE,
+                   priv->context_pane,
+                   "position",
+                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+  gtk_widget_show (priv->context_pane);
+
+  gtk_paned_pack1 (GTK_PANED (priv->context_pane), priv->content_pane,
+                   FALSE, TRUE);
+  gtk_box_pack_start (GTK_BOX (tab), priv->context_pane, TRUE, TRUE, 0);
+
+  /* Vertical context box (TM, context etc ) */
+  vcontext_box = gtk_vbox_new (FALSE, 6);
+  gtk_widget_show (vcontext_box);
+  gtk_paned_pack2 (GTK_PANED (priv->context_pane), vcontext_box,
+                   TRUE, TRUE);
+
+  /* TM */
+  priv->translation_memory = gtr_translation_memory_ui_new (GTK_WIDGET (tab));
+  gtk_widget_show (priv->translation_memory);
+  gtk_box_pack_start (GTK_BOX (vcontext_box), priv->translation_memory,
+                      TRUE, TRUE, 0);
+
+  /* Lateral panel */
+  tab->priv->lateral_panel = gtk_notebook_new ();
+  gtk_widget_show (tab->priv->lateral_panel);
+  gtk_box_pack_start (GTK_BOX (vcontext_box), tab->priv->lateral_panel,
+                      TRUE, TRUE, 0);
+
+  /* Context */
+  priv->context = gtr_context_panel_new (GTK_WIDGET (tab));
+  gtk_widget_show (priv->context);
+  gtr_tab_add_widget_to_lateral_panel (tab, priv->context, _("Context"));
 }
 
 static void
@@ -772,15 +703,21 @@ gtr_tab_init (GtrTab * tab)
 {
   tab->priv = GTR_TAB_GET_PRIVATE (tab);
 
+  tab->priv->files_settings = g_settings_new ("org.gnome.gtranslator.preferences.files");
+  tab->priv->editor_settings = g_settings_new ("org.gnome.gtranslator.preferences.editor");
+  tab->priv->state_settings = g_settings_new ("org.gnome.gtranslator.state.window");
+
   g_signal_connect (tab, "message-changed", G_CALLBACK (update_status), NULL);
 
   gtr_tab_draw (tab);
 
   /* Manage auto save data */
-  tab->priv->autosave = gtr_prefs_manager_get_autosave ();
+  tab->priv->autosave = g_settings_get_boolean (tab->priv->files_settings,
+                                                GTR_SETTINGS_AUTO_SAVE);
   tab->priv->autosave = (tab->priv->autosave != FALSE);
 
-  tab->priv->autosave_interval = gtr_prefs_manager_get_autosave_interval ();
+  tab->priv->autosave_interval = g_settings_get_int (tab->priv->files_settings,
+                                                     GTR_SETTINGS_AUTO_SAVE_INTERVAL);
   if (tab->priv->autosave_interval <= 0)
     tab->priv->autosave_interval = 1;
 }
@@ -790,9 +727,6 @@ gtr_tab_finalize (GObject * object)
 {
   GtrTab *tab = GTR_TAB (object);
 
-  if (tab->priv->po)
-    g_object_unref (tab->priv->po);
-
   if (tab->priv->timer != NULL)
     g_timer_destroy (tab->priv->timer);
 
@@ -802,6 +736,38 @@ gtr_tab_finalize (GObject * object)
   G_OBJECT_CLASS (gtr_tab_parent_class)->finalize (object);
 }
 
+static void
+gtr_tab_dispose (GObject * object)
+{
+  GtrTab *tab = GTR_TAB (object);
+
+  if (tab->priv->po != NULL)
+    {
+      g_object_unref (tab->priv->po);
+      tab->priv->po = NULL;
+    }
+
+  if (tab->priv->files_settings != NULL)
+    {
+      g_object_unref (tab->priv->files_settings);
+      tab->priv->files_settings = NULL;
+    }
+
+  if (tab->priv->editor_settings != NULL)
+    {
+      g_object_unref (tab->priv->editor_settings);
+      tab->priv->editor_settings = NULL;
+    }
+
+  if (tab->priv->state_settings != NULL)
+    {
+      g_object_unref (tab->priv->state_settings);
+      tab->priv->state_settings = NULL;
+    }
+
+  G_OBJECT_CLASS (gtr_tab_parent_class)->dispose (object);
+}
+
 static void
 gtr_tab_get_property (GObject * object,
                       guint prop_id, GValue * value, GParamSpec * pspec)
@@ -850,9 +816,9 @@ gtr_tab_class_init (GtrTabClass * klass)
   g_type_class_add_private (klass, sizeof (GtrTabPrivate));
 
   object_class->finalize = gtr_tab_finalize;
+  object_class->dispose = gtr_tab_dispose;
   object_class->set_property = gtr_tab_set_property;
   object_class->get_property = gtr_tab_get_property;
-  klass->showed_message = gtr_tab_showed_message;
   klass->message_edition_finished = gtr_tab_edition_finished;
 
   /* Signals */
@@ -884,6 +850,15 @@ gtr_tab_class_init (GtrTabClass * klass)
                   G_TYPE_POINTER);
 
   /* Properties */
+  g_object_class_install_property (object_class,
+                                   PROP_NAME,
+                                   g_param_spec_string ("name",
+                                                        "Name",
+                                                        "The tab's name",
+                                                        NULL,
+                                                        G_PARAM_READABLE |
+                                                        G_PARAM_STATIC_STRINGS));
+
   g_object_class_install_property (object_class,
                                    PROP_AUTOSAVE,
                                    g_param_spec_boolean ("autosave",
@@ -924,17 +899,22 @@ gtr_tab_new (GtrPo * po)
 
   tab = g_object_new (GTR_TYPE_TAB, NULL);
 
+  /* FIXME: make the po a property */
   tab->priv->po = po;
   g_object_set_data (G_OBJECT (po), GTR_TAB_KEY, tab);
+
+  g_signal_connect (po, "notify::location",
+                    G_CALLBACK (on_location_notify), tab);
+
+  g_signal_connect (po, "notify::state",
+                    G_CALLBACK (on_state_notify), tab);
+
   install_autosave_timeout_if_needed (tab);
 
-  /*
-   * Now we have to initialize the number of msgstr tabs
-   */
+  /* Now we have to initialize the number of msgstr tabs */
   gtr_tab_add_msgstr_tabs (tab);
 
-  gtr_message_table_populate (GTR_MESSAGE_TABLE
-                              (tab->priv->message_table),
+  gtr_message_table_populate (GTR_MESSAGE_TABLE (tab->priv->message_table),
                               gtr_po_get_messages (tab->priv->po));
 
   gtk_widget_show (GTK_WIDGET (tab));
@@ -945,7 +925,7 @@ gtr_tab_new (GtrPo * po)
  * gtr_tab_get_po:
  * @tab: a #GtrTab
  *
- * Return value: the #GtrPo stored in the #GtrTab
+ * Return value: (transfer none): the #GtrPo stored in the #GtrTab
 **/
 GtrPo *
 gtr_tab_get_po (GtrTab * tab)
@@ -953,20 +933,6 @@ gtr_tab_get_po (GtrTab * tab)
   return tab->priv->po;
 }
 
-/**
- * gtr_tab_get_panel:
- * @tab: a #GtranslationTab
- * 
- * Return value: the horizontal notebook of the #GtranslationTab
-**/
-GtkWidget *
-gtr_tab_get_panel (GtrTab * tab)
-{
-  g_return_val_if_fail (tab != NULL, NULL);
-
-  return tab->priv->panel;
-}
-
 /**
  * gtr_tab_get_active_trans_tab:
  * @tab: a #GtranslationTab
@@ -984,7 +950,7 @@ gtr_tab_get_active_trans_tab (GtrTab * tab)
  * gtr_tab_get_context_panel:
  * @tab: a #GtrTab
  *
- * Return value: the #GtranslaorContextPanel
+ * Return value: (transfer none): the #GtranslaorContextPanel
  */
 GtrContextPanel *
 gtr_tab_get_context_panel (GtrTab * tab)
@@ -996,7 +962,7 @@ gtr_tab_get_context_panel (GtrTab * tab)
  * gtr_tab_get_translation_memory_ui:
  * @tab: a #GtrTab
  *
- * Returns: the #GtrTranslationMemoryUi panel.
+ * Returns: (transfer none): the #GtrTranslationMemoryUi panel.
  */
 GtkWidget *
 gtr_tab_get_translation_memory_ui (GtrTab * tab)
@@ -1010,7 +976,7 @@ gtr_tab_get_translation_memory_ui (GtrTab * tab)
  * gtr_tab_get_active_view:
  * @tab: a #GtranslationTab
  *
- * Return value: the active page of the translation notebook.
+ * Return value: (transfer none): the active page of the translation notebook.
 **/
 GtrView *
 gtr_tab_get_active_view (GtrTab * tab)
@@ -1030,7 +996,7 @@ gtr_tab_get_active_view (GtrTab * tab)
  *
  * Returns all the views currently present in #GtranslationTab
  *
- * Return value: a newly allocated list of #GtranslationTab objects
+ * Return: (transfer container): a newly allocated list of #GtranslationTab objects
  */
 GList *
 gtr_tab_get_all_views (GtrTab * tab, gboolean original, gboolean translated)
@@ -1061,34 +1027,6 @@ gtr_tab_get_all_views (GtrTab * tab, gboolean original, gboolean translated)
   return ret;
 }
 
-/**
- * gtr_tab_get_name:
- * @tab: a #GtrTab 
- * 
- * Return value: a new allocated string with the name of the @tab.
- */
-gchar *
-gtr_tab_get_name (GtrTab * tab)
-{
-  GtrHeader *header;
-  GtrPoState state;
-  const gchar *str;
-  gchar *tab_name;
-
-  header = gtr_po_get_header (tab->priv->po);
-  state = gtr_po_get_state (tab->priv->po);
-
-  str = gtr_header_get_prj_id_version (header);
-
-  if (state == GTR_PO_STATE_MODIFIED)
-    {
-      tab_name = g_strdup_printf ("*%s", str);
-      return tab_name;
-    }
-
-  return g_strdup (str);
-}
-
 /**
  * gtr_tab_message_go_to:
  * @tab: a #GtrTab
@@ -1187,6 +1125,52 @@ gtr_tab_message_go_to (GtrTab * tab,
                    GTR_MSG (to_go->data));
 }
 
+/**
+ * _gtr_tab_get_name:
+ * @tab: a #GtrTab 
+ * 
+ * Return value: a new allocated string with the name of the @tab.
+ */
+gchar *
+_gtr_tab_get_name (GtrTab *tab)
+{
+  GtrHeader *header;
+  GtrPoState state;
+  const gchar *str;
+  gchar *tab_name;
+
+  header = gtr_po_get_header (tab->priv->po);
+  state = gtr_po_get_state (tab->priv->po);
+
+  str = gtr_header_get_prj_id_version (header);
+
+  if (state == GTR_PO_STATE_MODIFIED)
+    {
+      tab_name = g_strdup_printf ("*%s", str);
+      return tab_name;
+    }
+
+  return g_strdup (str);
+}
+
+gchar *
+_gtr_tab_get_tooltips (GtrTab *tab)
+{
+  GFile *location;
+  gchar *tooltips;
+  gchar *path;
+
+  location = gtr_po_get_location (tab->priv->po);
+  path = g_file_get_path (location);
+  g_object_unref (location);
+
+  /* Translators: Path to the document opened */
+  tooltips = g_strdup_printf ("<b>%s</b> %s", _("Path:"), path);
+  g_free (path);
+
+  return tooltips;
+}
+
 /**
  * _gtr_tab_can_close:
  * @tab: a #GtrTab
@@ -1207,7 +1191,7 @@ _gtr_tab_can_close (GtrTab * tab)
  *
  * Returns the #GtrTab for a specific #GtrPo.
  *
- * Returns: the #GtrTab for a specific #GtrPo
+ * Returns: (transfer none): the #GtrTab for a specific #GtrPo
  */
 GtrTab *
 gtr_tab_get_from_document (GtrPo * po)
@@ -1423,7 +1407,7 @@ gtr_tab_copy_to_translation (GtrTab * tab)
 {
   GtkTextBuffer *msgstr, *msgid;
   gint page_index;
-  const gchar *text;
+  gchar *text;
   GtkTextIter start, end;
 
   g_return_if_fail (GTR_IS_TAB (tab));
@@ -1439,6 +1423,7 @@ gtr_tab_copy_to_translation (GtrTab * tab)
   gtk_text_buffer_get_bounds (msgid, &start, &end);
   text = gtk_text_buffer_get_text (msgid, &start, &end, FALSE);
   gtk_text_buffer_set_text (msgstr, text, -1);
+  g_free (text);
   gtk_text_buffer_end_user_action (msgstr);
 }
 
